@@ -7,4 +7,4 @@ Store your API key in this file -- that way the `RT` class can be initialized
 without having to pass it in as an argument.
 """
 
-API_KEY = ''
+API_KEY = '6wtvhhz7s9y7v5u5my36jg63'
